@@ -135,6 +135,8 @@ pub struct AquaSlsaProvenance {
     pub repo_name: Option<String>,
     pub url: Option<String>,
     pub asset: Option<String>,
+    pub source_uri: Option<String>,
+    pub source_tag: Option<String>,
 }
 
 #[derive(Debug, Deserialize, Clone)]
@@ -706,6 +708,12 @@ impl AquaSlsaProvenance {
         if let Some(asset) = other.asset {
             self.asset = Some(asset);
         }
+        if let Some(source_uri) = other.source_uri {
+            self.source_uri = Some(source_uri);
+        }
+        if let Some(source_tag) = other.source_tag {
+            self.source_tag = Some(source_tag);
+        }
     }
 }
 
