@@ -403,15 +403,23 @@ impl AquaBackend {
                         return Ok(());
                     }
                 };
+                let source_uri = slsa
+                    .source_uri
+                    .clone()
+                    .unwrap_or_else(|| format!("github.com/{repo}"));
                 let mut cmd = CmdLineRunner::new(slsa_bin)
                     .arg("verify-artifact")
                     .arg(tv.download_path().join(filename))
                     .arg("--provenance-repository")
                     .arg(&repo)
                     .arg("--source-uri")
-                    .arg(format!("github.com/{repo}"))
+                    .arg(source_uri)
                     .arg("--provenance-path")
                     .arg(provenance_path);
+                let source_tag = slsa.source_tag.clone().unwrap_or_else(|| v.to_string());
+                if source_tag != "-" {
+                    cmd = cmd.arg("--source-tag").arg(source_tag);
+                }
                 cmd = cmd.with_pr(&ctx.pr);
                 cmd.execute()?;
             } else {
